summaryrefslogtreecommitdiff
path: root/public/fpdf_annot.h
diff options
context:
space:
mode:
Diffstat (limited to 'public/fpdf_annot.h')
-rw-r--r--public/fpdf_annot.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/public/fpdf_annot.h b/public/fpdf_annot.h
index d5ef54cf3b..f4dc03a2c4 100644
--- a/public/fpdf_annot.h
+++ b/public/fpdf_annot.h
@@ -302,24 +302,24 @@ FPDFAnnot_HasAttachmentPoints(FPDF_ANNOTATION annot);
// with quadpoints, then update the bounding box too if the new quadpoints
// define a bigger one.
//
// annot - handle to an annotation.
// quadPoints - the quadpoints to be set.
//
// Returns true if successful.
FPDF_EXPORT FPDF_BOOL FPDF_CALLCONV
FPDFAnnot_SetAttachmentPoints(FPDF_ANNOTATION annot,
- const FS_QUADPOINTSF* quadPoints);
+ const FS_QUADPOINTSF* quad_points);
// Experimental API.
// Get the attachment points (i.e. quadpoints) of an annotation.
//
// annot - handle to an annotation.
// quadPoints - receives the quadpoints; must not be NULL.
//
// Returns true if successful.
FPDF_EXPORT FPDF_BOOL FPDF_CALLCONV
FPDFAnnot_GetAttachmentPoints(FPDF_ANNOTATION annot,
- FS_QUADPOINTSF* quadPoints);
+ FS_QUADPOINTSF* quad_points);
// Experimental API.
// Set the annotation rectangle defining the location of the annotation. If the
@@ -302,24 +302,24 @@ FPDFAnnot_HasAttachmentPoints(FPDF_ANNOTATION annot);
// define a bigger one.
//
-// annot - handle to an annotation.
-// quadPoints - the quadpoints to be set.
+// annot - handle to an annotation.
+// quad_points - the quadpoints to be set.
//
// Returns true if successful.
@@ -302,24 +302,24 @@ FPDFAnnot_HasAttachmentPoints(FPDF_ANNOTATION annot);
// Get the attachment points (i.e. quadpoints) of an annotation.
//
-// annot - handle to an annotation.
-// quadPoints - receives the quadpoints; must not be NULL.
+// annot - handle to an annotation.
+// quad_points - receives the quadpoints; must not be NULL.
//
// Returns true if successful.